function plothopd(W,beta,Vinit,eta,iters)
%plothopd(W,beta,Vinit,eta,iters)
%
%PLOTHOPD
%
% This function simulates a 100 neuron Hopfield net by calling
% simhop and then shows a movie of the resulting S state vector trace
% arranged as a 10 by 10 picture.
%
% W     is the connection matrix (should be symmetric)
% beta  is the gain of the activation function (tanh by befault)
% Vinit is the initial condition vector for the V's
% eta   is the timestep for the Euler integration
% iters is the number of iterations to simulate
%

[Vtrace,Strace] = simhop(W,beta,Vinit,eta,iters);

figure;
colormap('gray');

for i=1:iters
  imagesc(reshape(Strace(:,i),10,10),[-1 1]);
  axis('square');
  drawnow;
end



